<?php
/**
 * @file
 * template.php
 */

require_once dirname(__FILE__) . '/inc/process.inc';
require_once dirname(__FILE__) . '/inc/theme.inc';

// Add base theme style sheets.
$base_stylesheets = array(
  'base.css',
  'typography.css',
  'drupal.css',
  'grid.css',
  'layout.css',
);
foreach ($base_stylesheets as $val) {
  drupal_add_css(
    drupal_get_path('theme', $GLOBALS['theme_key']) . '/css/' . $val,
    array('group' => CSS_THEME)
  );
}

// Add style sheet overrides.
if (module_exists('contextual')) {
  drupal_add_css(
    drupal_get_path('theme', $GLOBALS['theme_key']) . '/css/core/contextual.css',
    array('group' => CSS_THEME)
  );
}
if (module_exists('comment')) {
  drupal_add_css(
    drupal_get_path('theme', $GLOBALS['theme_key']) . '/css/core/comment.css',
    array('group' => CSS_THEME)
  );
}
if (module_exists('search')) {
  drupal_add_css(
    drupal_get_path('theme', $GLOBALS['theme_key']) . '/css/core/search.css',
    array('group' => CSS_THEME)
  );
}
if (module_exists('date_api')) {
  drupal_add_css(
    drupal_get_path('theme', $GLOBALS['theme_key']) . '/css/contrib/date.css',
    array('group' => CSS_THEME)
  );
}

// Add design theme style sheets.
$design_stylesheets = array(
  'design.css',
  'mobile-menu.css',
);
// Add drop-down menu styles.
if (theme_get_setting('use_dropdowns')) {
  $design_stylesheets[] = 'dropdown-menu.css';
}
foreach ($design_stylesheets as $val) {
  drupal_add_css(
    drupal_get_path('theme', $GLOBALS['theme_key']) . '/css/' . $val,
    array('group' => CSS_THEME)
  );
}

// Add theme scripts.
$theme_scripts = array(
  'script.js',
  'mobile-menu.js',
);
// Add drop-down menu script.
if (theme_get_setting('use_dropdowns')) {
  $theme_scripts[] = 'dropdown-menu.js';
}
foreach ($theme_scripts as $val) {
  drupal_add_js(
    drupal_get_path('theme', $GLOBALS['theme_key']) . '/js/' . $val,
    array('scope' => 'footer', 'every_page' => TRUE)
  );
}

// Add Holmes style sheet.
if (theme_get_setting('use_holmes') && user_access('administer nodes')) {
  drupal_add_css(drupal_get_path('theme', $GLOBALS['theme_key']) . '/css/holmes.css', array('group' => CSS_THEME));
}

// Add IE conditional style sheets.
$ie_stylesheets = array(
  'ie.css',
  'fallback.css',
);
foreach ($ie_stylesheets as $val) {
  drupal_add_css(
    drupal_get_path('theme', $GLOBALS['theme_key']) . '/css/' . $val,
    array(
      'group' => CSS_THEME,
      'browsers' => array('IE' => 'lt IE 9', '!IE' => FALSE),
    )
  );
}

/**
 * Implements hook_html_head_alter().
 */
function mojo_html_head_alter(&$head_elements) {

  // HTML5 charset declaration.
  $head_elements['system_meta_content_type']['#attributes'] = array(
    'charset' => 'utf-8',
  );

  // Add handheld friendly meta tag.
  if (theme_get_setting('use_handheld_friendly')) {
    $head_elements['handheld_friendly'] = array(
      '#type' => 'html_tag',
      '#tag' => 'meta',
      '#attributes' => array(
        'name' => 'HandheldFriendly',
        'content' => 'true',
      ),
    );
  }

  // Add mobile optimized meta tag.
  if (theme_get_setting('use_mobile_optimized')) {
    $head_elements['mobile_optimized'] = array(
      '#type' => 'html_tag',
      '#tag' => 'meta',
      '#attributes' => array(
        'name' => 'MobileOptimized',
        'content' => 'width',
      ),
    );
  }

  // Add iOS mobile meta tags.
  if (theme_get_setting('use_ios_meta')) {
    $head_elements['ios_web_app'] = array(
      '#type' => 'html_tag',
      '#tag' => 'meta',
      '#attributes' => array(
        'name' => 'apple-mobile-web-app-capable',
        'content' => 'yes',
      ),
    );
    $head_elements['ios_status_bar'] = array(
      '#type' => 'html_tag',
      '#tag' => 'meta',
      '#attributes' => array(
        'name' => 'apple-mobile-web-app-status-bar-style',
        'content' => 'black-translucent',
      ),
    );
  }

  // Optimize mobile viewport.
  if (theme_get_setting('use_mobile_viewport')) {
    $head_elements['mobile_viewport'] = array(
      '#type' => 'html_tag',
      '#tag' => 'meta',
      '#attributes' => array(
        'name' => 'viewport',
        'content' => filter_xss(theme_get_setting('mobile_viewport_value')),
      ),
    );
  }

  // Force IE to use Chrome Frame if installed.
  $meta_compatible_content = 'IE=edge';
  if (theme_get_setting('use_chrome_frame')) {
    $meta_compatible_content = 'IE=edge,chrome=1';
  }
  $head_elements['chrome_frame'] = array(
    '#type' => 'html_tag',
    '#tag' => 'meta',
    '#attributes' => array(
      'http-equiv' => 'X-UA-Compatible',
      'content' => $meta_compatible_content,
    ),
  );

  // Remove image toolbar in IE.
  $head_elements['ie_image_toolbar'] = array(
    '#type' => 'html_tag',
    '#tag' => 'meta',
    '#attributes' => array(
      'http-equiv' => 'ImageToolbar',
      'content' => 'false',
    ),
  );

  // Better font rendering in IE.
  $head_elements['ie_cleartype'] = array(
    '#type' => 'html_tag',
    '#tag' => 'meta',
    '#attributes' => array(
      'http-equiv' => 'cleartype',
      'content' => 'on',
    ),
  );
}

/**
 * Implements hook_js_alter().
 */
function mojo_js_alter(&$js) {

  // Unwanted scripts.
  $remove[] = drupal_get_path('module', 'panels') . '/js/panels.js';

  // Remove unwanted scripts.
  foreach ($remove as $val) {
    unset($js[$val]);
  }

  // Optimize the scope of scripts for front-end performance.
  if (theme_get_setting('optimize_scripts')) {

    // Scripts that go in the header.
    $header_scripts = array();
    if (module_exists('modernizr')) {
      $header_scripts[] = drupal_get_path('module', 'modernizr') . '/modernizr.min.js';
    }
    if (module_exists('respondjs')) {
      $header_scripts[] = drupal_get_path('module', 'respondjs') . '/lib/respond.min.js';
      $header_scripts[] = 'sites/all/libraries/respondjs/respond.min.js';
    }

    // Move all scripts to the footer.
    foreach ($js as $key => $script) {
      $js[$key]['scope'] = 'footer';

      // Move header scripts to the top.
      foreach ($header_scripts as $item => $value) {
        if ($key == $value) {
          $js[$key]['scope'] = 'header';
        }
      }
    }
  }
}

/**
 * Implements hook_css_alter().
 */
function mojo_css_alter(&$css) {

  // Unwanted core stylesheets.
  $remove[] = 'misc/vertical-tabs.css';
  $remove[] = 'misc/vertical-tabs-rtl.css';
  $remove[] = drupal_get_path('module', 'field') . '/theme/field.css';
  $remove[] = drupal_get_path('module', 'field') . '/theme/field-rtl.css';
  $remove[] = drupal_get_path('module', 'file') . '/file.css';
  $remove[] = drupal_get_path('module', 'filter') . '/filter.css';
  $remove[] = drupal_get_path('module', 'node') . '/node.css';
  $remove[] = drupal_get_path('module', 'system') . '/system.admin.css';
  $remove[] = drupal_get_path('module', 'system') . '/system.admin-rtl.css';
  $remove[] = drupal_get_path('module', 'system') . '/system.base.css';
  $remove[] = drupal_get_path('module', 'system') . '/system.base-rtl.css';
  $remove[] = drupal_get_path('module', 'system') . '/system.maintenance.css';
  $remove[] = drupal_get_path('module', 'system') . '/system.menus.css';
  $remove[] = drupal_get_path('module', 'system') . '/system.menus-rtl.css';
  $remove[] = drupal_get_path('module', 'system') . '/system.messages.css';
  $remove[] = drupal_get_path('module', 'system') . '/system.messages-rtl.css';
  $remove[] = drupal_get_path('module', 'system') . '/system.theme.css';
  $remove[] = drupal_get_path('module', 'system') . '/system.theme-rtl.css';
  $remove[] = drupal_get_path('module', 'user') . '/user.css';
  $remove[] = drupal_get_path('module', 'user') . '/user-rtl.css';

  // Unwanted contrib stylesheets.
  $remove[] = drupal_get_path('module', 'ctools') . '/css/ctools.css';
  $remove[] = drupal_get_path('module', 'panels') . '/css/panels.css';
  $remove[] = drupal_get_path('module', 'views') . '/css/views.css';
  $remove[] = drupal_get_path('module', 'views') . '/css/views-rtl.css';

  // Remove unwanted style sheets.
  foreach ($remove as $val) {
    unset($css[$val]);
  }
}
